==> formatter_suite-8.x-1.0.tar.gz: formatter_suite/src/Plugin/Field/FieldFormatter/GeneralNumberListFormatter.php <==
<?php

namespace Drupal\formatter_suite\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\Xss;
use Drupal\Component\Render\FormattableMarkup;

/**
 * Formats multiple numbers as a list.
 *
 * For multi-value fields, Drupal invokes the formatter with the list of
 * field values and each one is formatted on its own. They are then added
 * to the page and separated only by spaces.
 *
 * This formatter presents a list of values as a group and formats them
 * as one of:
 *   - Single line list using <div> around the group, and <span> for each value.
 *   - Numbered list using <ol> around the group, and <li> for each value.
 *   - Bulleted list using <ul> around the group, and <li> for each value.
 *   - Non-bulleted list using <div> around the group, and <div> for each value.
 *
 * Optional list separator text is added between each value, such as a comma.
 *
 * @ingroup formatter_suite
 *
 * @FieldFormatter(
 *   id          = "formatter_suite_general_number_list",
 *   label       = @Translation("Formatter Suite - General number list"),
 *   weight      = 1001,
 *   field_types = {
 *     "decimal",
 *     "float",
 *     "integer",
 *   }
 * )
 */
class GeneralNumberListFormatter extends GeneralNumberFormatter {

  /*---------------------------------------------------------------------
   *
   * Configuration.
   *
   *---------------------------------------------------------------------*/

  /**
   * Returns an array of list styles.
   *
   * @return string[]
   *   Returns an associative array with internal names as keys and
   *   human-readable translated names as values.
   */
  protected static function getListStyles() {
    return [
      'span' => t('Single line list'),
      'ol'   => t('Numbered list'),
      'ul'   => t('Bulleted list'),
      'div'  => t('Non-bulleted list'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'listStyle'     => 'span',
      'listSeparator' => ',',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();

    $listStyles    = $this->getListStyles();
    $listStyle     = $this->getSetting('listStyle');
    $listSeparator = $this->getSetting('listSeparator');

    // Summarize.
    $summary[] = $listStyles[$listStyle];

    if (empty($listSeparator) === FALSE) {
      // Include the list separator.
      //
      // The separator entered by the admin may include HTML entities and
      // minor HTML, but it should not include dangerous HTML. So we use
      // Xss to filter out problems. This is more permissive than passing
      // the text to t() as an argument, which will escape everything and
      // ruin inclusion of minor HTML and entities.
      $listSeparator = Xss::filterAdmin($this->getSetting('listSeparator'));
      $summary[] = t(
        'Separated by "@listSeparator"',
        [
          '@listSeparator' => new FormattableMarkup($listSeparator, []),
        ]);
    }

    return $summary;
  }

  /*---------------------------------------------------------------------
   *
   * Settings form.
   *
   *---------------------------------------------------------------------*/

  /**
   * Returns a brief description of the formatter.
   *
   * @return string
   *   Returns a brief translated description of the formatter.
   */
  protected function getDescription() {
    return t('Format multi-value fields as a list.');
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $formState) {
    // Get the parent's form, which includes a lot of settings for
    // formatting numbers.
    $elements = parent::settingsForm($form, $formState);

    $weight = -100;

    // Prompt for each setting.
    $elements['listStyle'] = [
      '#title'         => t('List style'),
      '#type'          => 'select',
      '#options'       => $this->getListStyles(),
      '#default_value' => $this->getSetting('listStyle'),
      '#weight'        => $weight++,
      '#wrapper_attributes' => [
        'class'        => [
          'formatter_suite-general-number-list-list-style',
        ],
      ],
    ];

    $elements['listSeparator'] = [
      '#title'         => t('Item separator'),
      '#type'          => 'textfield',
      '#size'          => 10,
      '#default_value' => $this->getSetting('listSeparator'),
      '#description'   => t('Optional text between each item, such as a comma.'),
      '#weight'        => $weight++,
      '#wrapper_attributes' => [
        'class'        => [
          'formatter_suite-general-number-list-list-separator',
        ],
      ],
    ];

    $elements['sectionBreak'] = [
      '#markup' => '<div class="formatter_suite-section-break"></div>',
      '#weight' => $weight++,
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  protected function sanitizeSettings() {
    // Get settings.
    $listStyle  = $this->getSetting('listStyle');
    $listStyles = $this->getListStyles();
    $defaults   = $this->defaultSettings();

    // Sanitize & validate.
    parent::sanitizeSettings();

    if (empty($listStyle) === TRUE ||
        isset($listStyles[$listStyle]) === FALSE) {
      $listStyle = $defaults['listStyle'];
      $this->setSetting('listStyle', $listStyle);
    }
  }

  /*---------------------------------------------------------------------
   *
   * View.
   *
   *---------------------------------------------------------------------*/

  /**
   * {@inheritdoc}
   */
  public function view(FieldItemListInterface $items, $langcode = NULL) {
    // Let the parent class set up a render array for all items.
    $build = parent::view($items, $langcode);

    // Replace the 'field' theme with ours, which supports lists.
    $build['#theme'] = 'formatter_suite_field_list';

    // Set the list style.
    $build['#list_style'] = $this->getSetting('listStyle');

    // Set the list separator.
    //
    // The separator text has been enter by an admin, so it is presumed
    // to be fairly safe. Run it through Xss::filterAdmin() to be sure.
    // This will retain any HTML entities or minor HTML, but block
    // dangerous items.
    //
    // Since we are filtering the admin's separator text ourselves,
    // we need to prevent TWIG from doing it again. This is done by
    // marking it as formatted markup.
    $listSeparator = Xss::filterAdmin($this->getSetting('listSeparator'));
    $build['#list_separator'] = new FormattableMarkup($listSeparator, []);

    return $build;
  }

}

==> formatter_suite-8.x-1.1.tar.gz: formatter_suite/src/Plugin/Field/FieldFormatter/GeneralNumberListFormatter.php <==
<?php

namespace Drupal\formatter_suite\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\Xss;
use Drupal\Component\Render\FormattableMarkup;

/**
 * Formats multiple numbers as a list.
 *
 * For multi-value fields, Drupal invokes the formatter with the list of
 * field values and each one is formatted on its own. They are then added
 * to the page and separated only by spaces.
 *
 * This formatter presents a list of values as a group and formats them
 * as one of:
 *   - Single line list using <div> around the group, and <span> for each value.
 *   - Numbered list using <ol> around the group, and <li> for each value.
 *   - Bulleted list using <ul> around the group, and <li> for each value.
 *   - Non-bulleted list using <div> around the group, and <div> for each value.
 *
 * Optional list separator text is added between each value, such as a comma.
 *
 * @ingroup formatter_suite
 *
 * @FieldFormatter(
 *   id          = "formatter_suite_general_number_list",
 *   label       = @Translation("Formatter Suite - General number list"),
 *   weight      = 1001,
 *   field_types = {
 *     "decimal",
 *     "float",
 *     "integer",
 *   }
 * )
 */
class GeneralNumberListFormatter extends GeneralNumberFormatter {

  /*---------------------------------------------------------------------
   *
   * Configuration.
   *
   *---------------------------------------------------------------------*/

  /**
   * Returns an array of list styles.
   *
   * @return string[]
   *   Returns an associative array with internal names as keys and
   *   human-readable translated names as values.
   */
  protected static function getListStyles() {
    return [
      'span' => t('Single line list'),
      'ol'   => t('Numbered list'),
      'ul'   => t('Bulleted list'),
      'div'  => t('Non-bulleted list'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return array_merge(
      [
        'listStyle'     => 'span',
        'listSeparator' => ',',
      ],
      parent::defaultSettings());
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();

    $listStyles    = $this->getListStyles();
    $listStyle     = $this->getSetting('listStyle');
    $listSeparator = $this->getSetting('listSeparator');

    // Summarize.
    $summary[] = $listStyles[$listStyle];

    if (empty($listSeparator) === FALSE) {
      // Include the list separator.
      //
      // The separator entered by the admin may include HTML entities and
      // minor HTML, but it should not include dangerous HTML. So we use
      // Xss to filter out problems. This is more permissive than passing
      // the text to t() as an argument, which will escape everything and
      // ruin inclusion of minor HTML and entities.
      $listSeparator = Xss::filterAdmin($this->getSetting('listSeparator'));
      $summary[] = $this->t(
        'Separated by "@listSeparator"',
        [
          '@listSeparator' => new FormattableMarkup($listSeparator, []),
        ]);
    }

    return $summary;
  }

  /*---------------------------------------------------------------------
   *
   * Settings form.
   *
   *---------------------------------------------------------------------*/

  /**
   * Returns a brief description of the formatter.
   *
   * @return string
   *   Returns a brief translated description of the formatter.
   */
  protected function getDescription() {
    return $this->t('Format multi-value fields as a list.');
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $formState) {
    // Get the parent's form, which includes a lot of settings for
    // formatting numbers.
    $elements = parent::settingsForm($form, $formState);

    $weight = -100;

    // Prompt for each setting.
    $elements['listStyle'] = [
      '#title'         => $this->t('List style'),
      '#type'          => 'select',
      '#options'       => $this->getListStyles(),
      '#default_value' => $this->getSetting('listStyle'),
      '#weight'        => $weight++,
      '#wrapper_attributes' => [
        'class'        => [
          'formatter_suite-general-number-list-list-style',
        ],
      ],
    ];

    $elements['listSeparator'] = [
      '#title'         => $this->t('Item separator'),
      '#type'          => 'textfield',
      '#size'          => 10,
      '#default_value' => $this->getSetting('listSeparator'),
      '#description'   => $this->t('Optional text between each item, such as a comma.'),
      '#weight'        => $weight++,
      '#wrapper_attributes' => [
        'class'        => [
          'formatter_suite-general-number-list-list-separator',
        ],
      ],
    ];

    $elements['sectionBreak'] = [
      '#markup' => '<div class="formatter_suite-section-break"></div>',
      '#weight' => $weight++,
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  protected function sanitizeSettings() {
    // Get settings.
    $listStyle  = $this->getSetting('listStyle');
    $listStyles = $this->getListStyles();
    $defaults   = $this->defaultSettings();

    // Sanitize & validate.
    parent::sanitizeSettings();

    if (empty($listStyle) === TRUE ||
        isset($listStyles[$listStyle]) === FALSE) {
      $listStyle = $defaults['listStyle'];
      $this->setSetting('listStyle', $listStyle);
    }
  }

  /*---------------------------------------------------------------------
   *
   * View.
   *
   *---------------------------------------------------------------------*/

  /**
   * {@inheritdoc}
   */
  public function view(FieldItemListInterface $items, $langcode = NULL) {
    // Let the parent class set up a render array for all items.
    $build = parent::view($items, $langcode);

    // Replace the 'field' theme with ours, which supports lists.
    $build['#theme'] = 'formatter_suite_field_list';

    // Set the list style.
    $build['#list_style'] = $this->getSetting('listStyle');

    // Set the list separator.
    //
    // The separator text has been enter by an admin, so it is presumed
    // to be fairly safe. Run it through Xss::filterAdmin() to be sure.
    // This will retain any HTML entities or minor HTML, but block
    // dangerous items.
    //
    // Since we are filtering the admin's separator text ourselves,
    // we need to prevent TWIG from doing it again. This is done by
    // marking it as formatted markup.
    $listSeparator = Xss::filterAdmin($this->getSetting('listSeparator'));
    $build['#list_separator'] = new FormattableMarkup($listSeparator, []);

    return $build;
  }

}
